package #
Date::Manip::Offset::off309;
# Copyright (c) 2008-2025 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'tzdata' is run.
#    Generated on: Sun Jun  1 17:32:44 EDT 2025
#    Data version: tzdata2025b
#    Code version: tzcode2025b

# This module contains data from the zoneinfo time zone database.  The original
# data was obtained from the URL:
#    ftp://ftp.iana.org/tz

use strict;
use warnings;
require 5.010000;

our ($VERSION);
$VERSION='6.98';
END { undef $VERSION; }

our ($Offset,%Offset);
END {
   undef $Offset;
   undef %Offset;
}

$Offset        = '-05:00:00';

%Offset        = (
   0 => [
      'america/new_york',
      'america/toronto',
      'america/lima',
      'america/panama',
      'america/grand_turk',
      'america/jamaica',
      'america/bogota',
      'america/eirunepe',
      'america/rio_branco',
      'america/detroit',
      'america/port-au-prince',
      'america/havana',
      'america/guayaquil',
      'america/iqaluit',
      'america/indiana/vevay',
      'america/indiana/indianapolis',
      'america/indiana/marengo',
      'america/indiana/winamac',
      'america/kentucky/louisville',
      'america/indiana/vincennes',
      'america/indiana/petersburg',
      'america/cancun',
      'america/kentucky/monticello',
      'etc/gmt-5',
      'e',
      'america/resolute',
      'america/indiana/knox',
      'america/indiana/tell_city',
      'america/rankin_inlet',
      'america/santo_domingo',
      'america/cambridge_bay',
      'america/managua',
      'pacific/galapagos',
      'america/merida',
      'america/menominee',
      'america/coyhaique',
      'america/punta_arenas',
      'america/santiago',
      'america/chicago',
      'america/moncton',
      ],
   1 => [
      'america/chicago',
      'america/winnipeg',
      'america/indiana/knox',
      'america/indiana/tell_city',
      'america/menominee',
      'america/rankin_inlet',
      'america/resolute',
      'pacific/easter',
      'america/matamoros',
      'america/north_dakota/center',
      'america/ojinaga',
      'america/north_dakota/new_salem',
      'america/north_dakota/beulah',
      'america/mexico_city',
      'america/monterrey',
      'america/merida',
      'america/bahia_banderas',
      'america/cancun',
      'america/indiana/petersburg',
      'america/indiana/vincennes',
      'america/indiana/winamac',
      'america/guatemala',
      'america/managua',
      'america/tegucigalpa',
      'america/kentucky/monticello',
      'america/cambridge_bay',
      'america/iqaluit',
      'america/chihuahua',
      'america/ciudad_juarez',
      'pacific/galapagos',
      'america/costa_rica',
      'america/el_salvador',
      'america/belize',
      'america/indiana/marengo',
      'america/kentucky/louisville',
      'america/indiana/indianapolis',
      'america/indiana/vevay',
      ],
);

1;
